# ory-keto-client

OryHydraClient - the Ruby gem for the ORY Keto

Ory Keto is a cloud native access control server providing best-practice patterns (RBAC, ABAC, ACL, AWS IAM Policies, Kubernetes Roles, ...) via REST APIs.

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: Latest
- Package version: v0.5.2
- Build package: org.openapitools.codegen.languages.RubyClientCodegen
For more information, please visit [https://www.ory.sh](https://www.ory.sh)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build ory-keto-client.gemspec
```

Then either install the gem locally:

```shell
gem install ./ory-keto-client-v0.5.2.gem
```

(for development, run `gem install --dev ./ory-keto-client-v0.5.2.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'ory-keto-client', '~> v0.5.2'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/ory/sdk, then add the following in the Gemfile:

    gem 'ory-keto-client', :git => 'https://github.com/ory/sdk.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'ory-keto-client'

api_instance = OryHydraClient::EnginesApi.new
flavor = 'flavor_example' # String | The ORY Access Control Policy flavor. Can be \"regex\", \"glob\", and \"exact\".
id = 'id_example' # String | The ID of the ORY Access Control Policy Role.
opts = {
  body: OryHydraClient::AddOryAccessControlPolicyRoleMembersBody.new # AddOryAccessControlPolicyRoleMembersBody | 
}

begin
  #Add a member to an ORY Access Control Policy Role
  result = api_instance.add_ory_access_control_policy_role_members(flavor, id, opts)
  p result
rescue OryHydraClient::ApiError => e
  puts "Exception when calling EnginesApi->add_ory_access_control_policy_role_members: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*OryHydraClient::EnginesApi* | [**add_ory_access_control_policy_role_members**](docs/EnginesApi.md#add_ory_access_control_policy_role_members) | **PUT** /engines/acp/ory/{flavor}/roles/{id}/members | Add a member to an ORY Access Control Policy Role
*OryHydraClient::EnginesApi* | [**delete_ory_access_control_policy**](docs/EnginesApi.md#delete_ory_access_control_policy) | **DELETE** /engines/acp/ory/{flavor}/policies/{id} | 
*OryHydraClient::EnginesApi* | [**delete_ory_access_control_policy_role**](docs/EnginesApi.md#delete_ory_access_control_policy_role) | **DELETE** /engines/acp/ory/{flavor}/roles/{id} | Delete an ORY Access Control Policy Role
*OryHydraClient::EnginesApi* | [**do_ory_access_control_policies_allow**](docs/EnginesApi.md#do_ory_access_control_policies_allow) | **POST** /engines/acp/ory/{flavor}/allowed | Check if a request is allowed
*OryHydraClient::EnginesApi* | [**get_ory_access_control_policy**](docs/EnginesApi.md#get_ory_access_control_policy) | **GET** /engines/acp/ory/{flavor}/policies/{id} | 
*OryHydraClient::EnginesApi* | [**get_ory_access_control_policy_role**](docs/EnginesApi.md#get_ory_access_control_policy_role) | **GET** /engines/acp/ory/{flavor}/roles/{id} | Get an ORY Access Control Policy Role
*OryHydraClient::EnginesApi* | [**list_ory_access_control_policies**](docs/EnginesApi.md#list_ory_access_control_policies) | **GET** /engines/acp/ory/{flavor}/policies | 
*OryHydraClient::EnginesApi* | [**list_ory_access_control_policy_roles**](docs/EnginesApi.md#list_ory_access_control_policy_roles) | **GET** /engines/acp/ory/{flavor}/roles | List ORY Access Control Policy Roles
*OryHydraClient::EnginesApi* | [**remove_ory_access_control_policy_role_members**](docs/EnginesApi.md#remove_ory_access_control_policy_role_members) | **DELETE** /engines/acp/ory/{flavor}/roles/{id}/members/{member} | Remove a member from an ORY Access Control Policy Role
*OryHydraClient::EnginesApi* | [**upsert_ory_access_control_policy**](docs/EnginesApi.md#upsert_ory_access_control_policy) | **PUT** /engines/acp/ory/{flavor}/policies | 
*OryHydraClient::EnginesApi* | [**upsert_ory_access_control_policy_role**](docs/EnginesApi.md#upsert_ory_access_control_policy_role) | **PUT** /engines/acp/ory/{flavor}/roles | Upsert an ORY Access Control Policy Role
*OryHydraClient::HealthApi* | [**is_instance_alive**](docs/HealthApi.md#is_instance_alive) | **GET** /health/alive | Check alive status
*OryHydraClient::HealthApi* | [**is_instance_ready**](docs/HealthApi.md#is_instance_ready) | **GET** /health/ready | Check readiness status
*OryHydraClient::VersionApi* | [**get_version**](docs/VersionApi.md#get_version) | **GET** /version | Get service version


## Documentation for Models

 - [OryHydraClient::AddOryAccessControlPolicyRoleMembersBody](docs/AddOryAccessControlPolicyRoleMembersBody.md)
 - [OryHydraClient::AuthorizationResult](docs/AuthorizationResult.md)
 - [OryHydraClient::HealthNotReadyStatus](docs/HealthNotReadyStatus.md)
 - [OryHydraClient::HealthStatus](docs/HealthStatus.md)
 - [OryHydraClient::InlineResponse500](docs/InlineResponse500.md)
 - [OryHydraClient::OryAccessControlPolicy](docs/OryAccessControlPolicy.md)
 - [OryHydraClient::OryAccessControlPolicyAllowedInput](docs/OryAccessControlPolicyAllowedInput.md)
 - [OryHydraClient::OryAccessControlPolicyRole](docs/OryAccessControlPolicyRole.md)
 - [OryHydraClient::Version](docs/Version.md)


## Documentation for Authorization

 All endpoints do not require authorization.

